@@ -16,9 +16,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the N'Ko language.
+"""
+This module represents the N'Ko language.
 
-.. seealso:: http://en.wikipedia.org/wiki/N'Ko_language
+.. seealso:: :wp:`N'Ko_language`
 """
 
 
