@@ -16,9 +16,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""This module represents the Sinhala language.
+"""
+This module represents the Sinhala language.
 
-.. seealso:: http://en.wikipedia.org/wiki/Sinhala_language
+.. seealso:: :wp:`Sinhala_language`
 """
 
 
@@ -29,5 +30,5 @@ class si(common.Common):
     """This class represents Sinhala."""
 
     ignoretests = {
-        'all': ["simplecaps", "startcaps"],
+        "all": ["simplecaps", "startcaps"],
     }
