@@ -19,6 +19,8 @@
 
 """Module for handling Android String and Plurals resource files."""
 
+from __future__ import annotations
+
 import copy
 import os
 import re
@@ -33,6 +35,18 @@ EOF = None
 WHITESPACE = " \n\t"  # Whitespace that we collapse.
 MULTIWHITESPACE = re.compile("[ \n\t]{2}(?!\\\\n)")
 
+ESCAPE_TRANSLATE = str.maketrans(
+    {
+        "\\": "\\\\",
+        # This will add non intrusive real newlines to
+        # ones in translation improving readability of result
+        "\n": "\n\\n",
+        "\t": "\\t",
+        "'": "\\'",
+        '"': '\\"',
+    }
+)
+
 
 class AndroidResourceUnit(base.TranslationUnit):
     """A single entry in the Android String resource file."""
@@ -48,11 +62,10 @@ class AndroidResourceUnit(base.TranslationUnit):
     def __init__(self, source, empty=False, xmlelement=None, **kwargs):
         if xmlelement is not None:
             self.xmlelement = xmlelement
+        elif self.hasplurals(source):
+            self.xmlelement = etree.Element("plurals")
         else:
-            if self.hasplurals(source):
-                self.xmlelement = etree.Element("plurals")
-            else:
-                self.xmlelement = etree.Element("string")
+            self.xmlelement = etree.Element("string")
         if source is not None:
             self.setid(source)
         super().__init__(source)
@@ -91,7 +104,7 @@ class AndroidResourceUnit(base.TranslationUnit):
         active_percent = False
         active_escape = False
         i = 0
-        text = list(text) + [EOF]
+        text = [*list(text), EOF]
         while i < len(text):
             c = text[i]
 
@@ -140,67 +153,61 @@ class AndroidResourceUnit(base.TranslationUnit):
                     del text[i]
                     i -= 1
                     active_escape = False
-            else:
-                if active_escape:
-                    # Handle the limited amount of escape codes
-                    # that we support.
-                    # TODO: What about \r, or \r\n?
-                    if c is EOF:
-                        # Basically like any other char, but put
-                        # this first so we can use the ``in`` operator
-                        # in the clauses below without issue.
-                        pass
-                    elif c in ("n", "N"):
-                        # Remove whitespace just before newline. Most likely this is result of
-                        # having real newline in the XML in front of \n.
-                        if i >= 2 and text[i - 2] == " ":
-                            offset = 2
-                        else:
-                            offset = 1
-                        text[i - offset : i + 1] = "\n"  # an actual newline
-                        i -= offset
-                    elif c in ("t", "T"):
-                        text[i - 1 : i + 1] = "\t"  # an actual tab
-                        i -= 1
-                    elif c == " ":
-                        text[i - 1 : i + 1] = " "  # an actual space
-                        i -= 1
-                    elif c in "\"'@?":
-                        text[i - 1 : i] = ""  # remove the backslash
-                        i -= 1
-                    elif c == "u":
-                        # Unicode sequence. Android is nice enough to deal
-                        # with those in a way which let's us just capture
-                        # the next 4 characters and raise an error if they
-                        # are not valid (rather than having to use a new
-                        # state to parse the unicode sequence).
-                        # Exception: In case we are at the end of the
-                        # string, we support incomplete sequences by
-                        # prefixing the missing digits with zeros.
-                        # Note: max(len()) is needed in the slice due to
-                        # trailing ``None`` element.
-                        max_slice = min(i + 5, len(text) - 1)
-                        codepoint_str = "".join(text[i + 1 : max_slice])
-                        if len(codepoint_str) < 4:
-                            codepoint_str = (
-                                "0" * (4 - len(codepoint_str)) + codepoint_str
-                            )
-                        try:
-                            # We can't trust int() to raise a ValueError,
-                            # it will ignore leading/trailing whitespace.
-                            if not codepoint_str.isalnum():
-                                raise ValueError(codepoint_str)
-                            codepoint = chr(int(codepoint_str, 16))
-                        except ValueError:
-                            raise ValueError("bad unicode escape sequence")
+            elif active_escape:
+                # Handle the limited amount of escape codes
+                # that we support.
+                # TODO: What about \r, or \r\n?
+                if c is EOF:
+                    # Basically like any other char, but put
+                    # this first so we can use the ``in`` operator
+                    # in the clauses below without issue.
+                    pass
+                elif c in ("n", "N"):
+                    # Remove whitespace just before newline. Most likely this is result of
+                    # having real newline in the XML in front of \n.
+                    offset = 2 if i >= 2 and text[i - 2] == " " else 1
+                    text[i - offset : i + 1] = "\n"  # an actual newline
+                    i -= offset
+                elif c in ("t", "T"):
+                    text[i - 1 : i + 1] = "\t"  # an actual tab
+                    i -= 1
+                elif c == " ":
+                    text[i - 1 : i + 1] = " "  # an actual space
+                    i -= 1
+                elif c in "\"'@?":
+                    text[i - 1 : i] = ""  # remove the backslash
+                    i -= 1
+                elif c == "u":
+                    # Unicode sequence. Android is nice enough to deal
+                    # with those in a way which let's us just capture
+                    # the next 4 characters and raise an error if they
+                    # are not valid (rather than having to use a new
+                    # state to parse the unicode sequence).
+                    # Exception: In case we are at the end of the
+                    # string, we support incomplete sequences by
+                    # prefixing the missing digits with zeros.
+                    # Note: max(len()) is needed in the slice due to
+                    # trailing ``None`` element.
+                    max_slice = min(i + 5, len(text) - 1)
+                    codepoint_str = "".join(text[i + 1 : max_slice])
+                    if len(codepoint_str) < 4:
+                        codepoint_str = "0" * (4 - len(codepoint_str)) + codepoint_str
+                    try:
+                        # We can't trust int() to raise a ValueError,
+                        # it will ignore leading/trailing whitespace.
+                        if not codepoint_str.isalnum():
+                            raise ValueError(codepoint_str)
+                        codepoint = chr(int(codepoint_str, 16))
+                    except ValueError:
+                        raise ValueError("bad unicode escape sequence")
 
-                        text[i - 1 : max_slice] = codepoint
-                        i -= 1
-                    else:
-                        # All others, remove, like Android does as well.
-                        text[i - 1 : i + 1] = ""
-                        i -= 1
-                    active_escape = False
+                    text[i - 1 : max_slice] = codepoint
+                    i -= 1
+                else:
+                    # All others, remove, like Android does as well.
+                    text[i - 1 : i + 1] = ""
+                    i -= 1
+                active_escape = False
 
             i += 1
 
@@ -211,8 +218,11 @@ class AndroidResourceUnit(base.TranslationUnit):
     def xml_escape_space(matchobj):
         return matchobj.group(0).replace("  ", r" \u0020")
 
-    def escape(self, text, quote_wrapping_whitespaces=True):
-        """Escape all the characters which need to be escaped in an Android XML
+    def escape(
+        self, text: str | None, quote_wrapping_whitespaces: bool = True
+    ) -> str | None:
+        """
+        Escape all the characters which need to be escaped in an Android XML
         file.
 
         :param text: Text to escape
@@ -221,23 +231,20 @@ class AndroidResourceUnit(base.TranslationUnit):
                double quotes.
         """
         if text is None:
-            return
+            return None
         if len(text) == 0:
             return ""
-        text = text.replace("\\", "\\\\")
-        # This will add non intrusive real newlines to
-        # ones in translation improving readability of result
-        text = text.replace("\n", "\n\\n")
-        text = text.replace("\t", "\\t")
-        text = text.replace("'", "\\'")
-        text = text.replace("?", "\\?")
-        text = text.replace('"', '\\"')
 
-        # @ needs to be escaped at start
-        if text.startswith("@"):
-            text = "\\@" + text[1:]
+        # Escape XML chars and whitespace
+        text = text.translate(ESCAPE_TRANSLATE)
+
+        # @ and ? needs to be escaped at start as this would be interpreted
+        # as string/style references
+        if text.startswith(("@", "?")):
+            text = f"\\{text}"
+
         # Quote strings with more whitespace
-        multispace = MULTIWHITESPACE.findall(text)
+        multispace = MULTIWHITESPACE.search(text)
         if quote_wrapping_whitespaces and (
             text[0] in WHITESPACE or text[-1] in WHITESPACE or multispace
         ):
@@ -258,33 +265,32 @@ class AndroidResourceUnit(base.TranslationUnit):
         if len(xmltarget) == 0:
             # There are no html markups, so unescaping it as plain text.
             return self.unescape(xmltarget.text)
+        # There are html markups, so clone it to perform unescaping for all elements.
+        cloned_target = copy.deepcopy(xmltarget)
+
+        # Unescaping texts.
+        if cloned_target.text is not None:
+            cloned_target.text = self.unescape(cloned_target.text, False)
+        for xmlelement in cloned_target.iterdescendants():
+            if xmlelement.text is not None and xmlelement.tag is not etree.Entity:
+                xmlelement.text = self.unescape(xmlelement.text, False)
+            if xmlelement.tail is not None:
+                xmlelement.tail = self.unescape(xmlelement.tail, False)
+
+        # Grab root text (using a temporary xml element for text escaping)
+        if cloned_target.text is not None:
+            tmp_element = etree.Element("t")
+            tmp_element.text = cloned_target.text
+            target = etree.tostring(tmp_element, encoding="unicode")[3:-4]
         else:
-            # There are html markups, so clone it to perform unescaping for all elements.
-            cloned_target = copy.deepcopy(xmltarget)
+            target = ""
 
-            # Unescaping texts.
-            if cloned_target.text is not None:
-                cloned_target.text = self.unescape(cloned_target.text, False)
-            for xmlelement in cloned_target.iterdescendants():
-                if xmlelement.text is not None and xmlelement.tag is not etree.Entity:
-                    xmlelement.text = self.unescape(xmlelement.text, False)
-                if xmlelement.tail is not None:
-                    xmlelement.tail = self.unescape(xmlelement.tail, False)
-
-            # Grab root text (using a temporary xml element for text escaping)
-            if cloned_target.text is not None:
-                tmp_element = etree.Element("t")
-                tmp_element.text = cloned_target.text
-                target = etree.tostring(tmp_element, encoding="unicode")[3:-4]
-            else:
-                target = ""
-
-            # Include markup as well
-            target += "".join(
-                etree.tostring(child, encoding="unicode")
-                for child in cloned_target.iterchildren()
-            )
-            return target
+        # Include markup as well
+        target += "".join(
+            etree.tostring(child, encoding="unicode")
+            for child in cloned_target.iterchildren()
+        )
+        return target
 
     def set_xml_text_plain(self, target, xmltarget):
         # Remove possible old elements
@@ -399,7 +405,7 @@ class AndroidResourceUnit(base.TranslationUnit):
             # of Android builts with broken plurals handling.
             if "other" not in plural_tags and "many" in plural_tags:
                 # Create copy here to avoid modifications to laguage.data
-                plural_tags = plural_tags + ["other"]
+                plural_tags = [*plural_tags, "other"]
                 plural_strings.append(plural_strings[-1])
 
             for plural_tag, plural_string in zip(plural_tags, plural_strings):
@@ -439,8 +445,7 @@ class AndroidResourceUnit(base.TranslationUnit):
                     prevSibling = prevSibling.getprevious()
 
             return "\n".join(comments)
-        else:
-            return super().getnotes(origin)
+        return super().getnotes(origin)
 
     def removenotes(self, origin=None):
         if (self.xmlelement is not None) and (self.xmlelement.getparent is not None):
@@ -459,11 +464,7 @@ class AndroidResourceUnit(base.TranslationUnit):
 
     @staticmethod
     def hasplurals(thing):
-        if isinstance(thing, multistring):
-            return True
-        elif isinstance(thing, list):
-            return True
-        return False
+        return isinstance(thing, (multistring, list))
 
 
 class AndroidResourceFile(lisa.LISAfile):
@@ -481,14 +482,15 @@ class AndroidResourceFile(lisa.LISAfile):
     XMLuppercaseEncoding = False
 
     def initbody(self):
-        """Initialises self.body so it never needs to be retrieved from the XML
+        """
+        Initialises self.body so it never needs to be retrieved from the XML
         again.
         """
         self.namespace = self.document.getroot().nsmap.get(None, None)
         self.body = self.document.getroot()
 
     def parse(self, xml):
-        """Populates this object from the given xml string"""
+        """Populates this object from the given xml string."""
         if not hasattr(self, "filename"):
             self.filename = getattr(xml, "name", "")
         if hasattr(xml, "read"):
@@ -526,7 +528,8 @@ class AndroidResourceFile(lisa.LISAfile):
         return target_lang
 
     def addunit(self, unit, new=True):
-        """Adds unit to the document
+        """
+        Adds unit to the document.
 
         In addition to the standard addunit, it also tries to move
         namespace definitions to the top <resources> element.
@@ -561,3 +564,7 @@ class AndroidResourceFile(lisa.LISAfile):
         # The top_nsmap was introduced in LXML 3.5.0
         if do_cleanup:
             etree.cleanup_namespaces(self.body, top_nsmap=newns)
+
+    def removeunit(self, unit):
+        unit.removenotes()
+        super().removeunit(unit)
