@@ -20,7 +20,6 @@
 
 from lxml import etree
 
-from translate.lang import data
 from translate.misc.xml_helpers import getText, namespaced, reindent
 from translate.storage import base
 
@@ -28,12 +27,21 @@ from translate.storage import base
 class FlatXMLUnit(base.TranslationUnit):
     """A single term in the XML file."""
 
-    def __init__(self, source=None,
-                 namespace=None, element_name="str", attribute_name="key",
-                 **kwargs):
-        self.namespace = namespace
-        self.element_name = element_name
-        self.attribute_name = attribute_name
+    DEFAULT_NAMESPACE = None
+    DEFAULT_ELEMENT_NAME = "str"
+    DEFAULT_ATTRIBUTE_NAME = "key"
+
+    def __init__(
+        self,
+        source=None,
+        namespace=None,
+        element_name=None,
+        attribute_name=None,
+        **kwargs,
+    ):
+        self.namespace = namespace or self.DEFAULT_NAMESPACE
+        self.element_name = element_name or self.DEFAULT_ELEMENT_NAME
+        self.attribute_name = attribute_name or self.DEFAULT_ATTRIBUTE_NAME
         self.xmlelement = etree.Element(self.namespaced(self.element_name))
         super().__init__(source, **kwargs)
 
@@ -59,7 +67,6 @@ class FlatXMLUnit(base.TranslationUnit):
     @target.setter
     def target(self, target):
         """Updates the translated string of this unit."""
-        target = data.forceunicode(target)
         if self.target == target:
             return
         self.xmlelement.text = target
@@ -77,11 +84,11 @@ class FlatXMLUnit(base.TranslationUnit):
         return getText(self.xmlelement)
 
     @classmethod
-    def createfromxmlElement(cls, element,
-                             namespace=None,
-                             element_name="str",
-                             attribute_name="key"):
-        """Attempts to create a unit from the passed element.
+    def createfromxmlElement(
+        cls, element, namespace=None, element_name="str", attribute_name="key"
+    ):
+        """
+        Attempts to create a unit from the passed element.
 
         element must not be None and must match the given element name
         (including namespace); otherwise None will be returned.
@@ -90,39 +97,59 @@ class FlatXMLUnit(base.TranslationUnit):
             return None
         if element.tag != namespaced(namespace, element_name):
             return None
-        unit = cls(source=None,
-                   namespace=namespace,
-                   element_name=element_name,
-                   attribute_name=attribute_name)
+        unit = cls(
+            source=None,
+            namespace=namespace,
+            element_name=element_name,
+            attribute_name=attribute_name,
+        )
         unit.xmlelement = element
         return unit
 
 
+class NOTPROVIDED:
+    pass
+
+
 class FlatXMLFile(base.TranslationStore):
-    """Class representing a flat XML file store"""
+    """Class representing a flat XML file store."""
 
     UnitClass = FlatXMLUnit
     _name = "Flat XML File"
     Mimetypes = ["text/xml"]
     Extensions = ["xml"]
 
-    def __init__(self,
-                 inputfile=None,
-                 sourcelanguage="en",
-                 targetlanguage=None,
-                 root_name="root",
-                 value_name="str",
-                 key_name="key",
-                 namespace=None,
-                 indent_chars="  ",
-                 trailing_eol=True,
-                 **kwargs):
-        self.root_name = root_name
-        self.value_name = value_name
-        self.key_name = key_name
-        self.namespace = namespace
-        self.indent_chars = indent_chars
-        self.trailing_eol = trailing_eol
+    DEFAULT_ROOT_NAME = "root"
+    DEFAULT_VALUE_NAME = "str"
+    DEFAULT_KEY_NAME = "key"
+    DEFAULT_NAMESPACE = None
+    DEFAULT_INDENT_CHARS = "  "
+    DEFAULT_TRAILING_EOL = True
+    XML_DECLARATION = True
+
+    def __init__(
+        self,
+        inputfile=None,
+        sourcelanguage="en",
+        targetlanguage=None,
+        root_name=None,
+        value_name=None,
+        key_name=None,
+        namespace=None,
+        indent_chars=NOTPROVIDED,
+        trailing_eol=None,
+        **kwargs,
+    ):
+        self.root_name = root_name or self.DEFAULT_ROOT_NAME
+        self.value_name = value_name or self.DEFAULT_VALUE_NAME
+        self.key_name = key_name or self.DEFAULT_KEY_NAME
+        self.namespace = namespace or self.DEFAULT_NAMESPACE
+        self.indent_chars = (
+            self.DEFAULT_INDENT_CHARS if indent_chars is NOTPROVIDED else indent_chars
+        )
+        self.trailing_eol = (
+            self.DEFAULT_TRAILING_EOL if trailing_eol is None else trailing_eol
+        )
 
         super().__init__(**kwargs)
         if inputfile is not None:
@@ -145,7 +172,7 @@ class FlatXMLFile(base.TranslationStore):
     def reindent(self):
         """Reindents the backing document to be consistent."""
         # no elements? nothing to do.
-        if not(len(self.root)):
+        if not (len(self.root)):
             pass
 
         if self.indent_chars is None:
@@ -162,7 +189,9 @@ class FlatXMLFile(base.TranslationStore):
 
     def serialize(self, out=None):
         self.reindent()
-        self.document.write(out, xml_declaration=True, encoding=self.encoding)
+        self.document.write(
+            out, xml_declaration=self.XML_DECLARATION, encoding=self.encoding
+        )
 
     def make_empty_file(self):
         """Initializes the backing document to be an empty root element."""
@@ -184,8 +213,9 @@ class FlatXMLFile(base.TranslationStore):
         self.encoding = self.document.docinfo.encoding
 
         root_name = self.namespaced(self.root_name)
-        assert self.root.tag == root_name, \
-            "expected root name to be %s but got %s" % (root_name, self.root.tag)
+        assert (
+            self.root.tag == root_name
+        ), f"expected root name to be {root_name} but got {self.root.tag}"
         if len(self.root):
             # we'd expect at least one child element to have the correct
             # name and attributes; otherwise the name parameters might've
@@ -193,20 +223,27 @@ class FlatXMLFile(base.TranslationStore):
             # coming up empty when the file actually contains entries.
             value_name = self.namespaced(self.value_name)
             matching_nodes = list(self.root.iterchildren(value_name))
-            assert len(matching_nodes), \
-                "expected value name to be %s but first node is %s" % (
-                    value_name, self.root[0].tag)
+            assert len(
+                matching_nodes
+            ), "expected value name to be {} but first node is {}".format(
+                value_name,
+                self.root[0].tag,
+            )
 
-            assert matching_nodes[0].get(self.key_name), \
-                "expected key attribute to be %s, found attribute(s): %s" % (
-                    self.key_name, ",".join(matching_nodes[0].attrib))
+            assert matching_nodes[0].get(
+                self.key_name
+            ), "expected key attribute to be {}, found attribute(s): {}".format(
+                self.key_name,
+                ",".join(matching_nodes[0].attrib),
+            )
 
         for entry in self.root:
             unit = self.UnitClass.createfromxmlElement(
                 entry,
                 namespace=self.namespace,
                 element_name=self.value_name,
-                attribute_name=self.key_name)
+                attribute_name=self.key_name,
+            )
             if unit is not None:
                 self.addunit(unit, new=False)
 
