@@ -16,7 +16,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-"""Module for handling Qt linguist (.ts) files.
+"""
+Module for handling Qt linguist (.ts) files.
 
 This will eventually replace the older ts.py which only supports the older
 format. While converters haven't been updated to use this module, we retain
@@ -73,10 +74,10 @@ class tsunit(lisa.LISAunit):
 
     statemap_r = {i[1]: i[0] for i in statemap.items()}
     _context = None
+    _locations = None
 
     def createlanguageNode(self, lang, text, purpose):
         """Returns an xml Element setup with given parameters."""
-
         assert purpose
         if purpose == "target":
             purpose = "translation"
@@ -119,8 +120,7 @@ class tsunit(lisa.LISAunit):
         if self.hasplural():
             numerus_nodes = targetnode.findall(self.namespaced("numerusform"))
             return multistring([node.text or "" for node in numerus_nodes])
-        else:
-            return targetnode.text or ""
+        return targetnode.text or ""
 
     @target.setter
     def target(self, target):
@@ -157,7 +157,7 @@ class tsunit(lisa.LISAunit):
         return self.xmlelement.get("numerus") == "yes"
 
     def addnote(self, text, origin=None, position="append"):
-        """Add a note specifically in the appropriate *comment* tag"""
+        """Add a note specifically in the appropriate *comment* tag."""
         current_notes = self.getnotes(origin)
         self.removenotes(origin)
         if origin in ["programmer", "developer", "source code"]:
@@ -211,7 +211,7 @@ class tsunit(lisa.LISAunit):
             self._gettargetnode().attrib.pop("type")
 
     def isreview(self):
-        """States whether this unit needs to be reviewed"""
+        """States whether this unit needs to be reviewed."""
         return self._gettype() == "unfinished"
 
     def isfuzzy(self):
@@ -233,10 +233,8 @@ class tsunit(lisa.LISAunit):
         if context_name is not None:
             if self.source:
                 return context_name + self.source
-            else:
-                return context_name
-        else:
-            return self.source
+            return context_name
+        return self.source
 
     def istranslatable(self):
         # Found a file in the wild with no context and an empty source. This
@@ -280,6 +278,7 @@ class tsunit(lisa.LISAunit):
         return "\n".join(contexts)
 
     def addlocation(self, location):
+        self._locations = None
         newlocation = etree.SubElement(self.xmlelement, self.namespaced("location"))
         try:
             filename, line = location.split(":", 1)
@@ -290,20 +289,63 @@ class tsunit(lisa.LISAunit):
         if line is not None:
             newlocation.set("line", line)
 
-    def getlocations(self):
+    def parse_locations(self):
         location_tags = self.xmlelement.iterfind(self.namespaced("location"))
         locations = []
+        last_location = None
         for location_tag in location_tags:
             location = location_tag.get("filename")
             line = location_tag.get("line")
-            if line:
-                if location:
-                    location += ":" + line
-                else:
-                    location = line
-            if location:
-                locations.append(location)
-        return locations
+            if line is not None and line.startswith(("+", "-")):
+                # Relative locations
+                if last_location is None and (
+                    previous_unit := self.get_previous_unit()
+                ):
+                    last_location = previous_unit.get_last_location()
+
+                offset = 0
+                if last_location:
+                    if not location:
+                        location = last_location[0]
+                    offset = last_location[1]
+                line = offset + int(line)
+            if location or line:
+                last_location = (location, line)
+                locations.append(last_location)
+        self._locations = locations
+
+    def get_last_location(self):
+        if self._locations is None:
+            self.parse_locations()
+
+        if not self._locations:
+            previous = self.get_previous_unit()
+            if previous is None:
+                return None
+            return previous.get_last_location()
+
+        return self._locations[-1]
+
+    def get_previous_unit(self):
+        found = None
+        for pos, unit in enumerate(self._store.units):
+            # Use is here to compare objects as __eq__ implementation in
+            # LISAUnit might give unexpected results
+            if unit is self:
+                found = pos
+                break
+        if not found or found == 0:
+            return None
+        return self._store.units[found - 1]
+
+    def getlocations(self):
+        if self._locations is None:
+            self.parse_locations()
+
+        return [
+            f"{location}{':' if location else ''}{line}"
+            for location, line in self._locations
+        ]
 
     def merge(self, otherunit, overwrite=False, comments=True, authoritative=False):
         super().merge(otherunit, overwrite, comments)
@@ -323,9 +365,8 @@ class tsunit(lisa.LISAunit):
             # format doesn't really do
             if self.target:
                 return self.S_FUZZY
-            else:
-                return self.S_UNTRANSLATED
-        elif type == "vanished":
+            return self.S_UNTRANSLATED
+        if type == "vanished":
             return self.S_OBSOLETE
         return self.statemap[type]
 
@@ -361,6 +402,7 @@ class tsfile(lisa.LISAfile):
 
     def __init__(self, *args, **kwargs):
         self._contextname = None
+        self.last_location = None
         super().__init__(*args, **kwargs)
 
     def initbody(self):
@@ -373,7 +415,8 @@ class tsfile(lisa.LISAfile):
             self.body = self.document.getroot()
 
     def getsourcelanguage(self):
-        """Get the source language for this .ts file.
+        """
+        Get the source language for this .ts file.
 
         The 'sourcelanguage' attribute was only added to the TS format in
         Qt v4.5. We return 'en' if there is no sourcelanguage set.
@@ -391,7 +434,8 @@ class tsfile(lisa.LISAfile):
         return lang
 
     def gettargetlanguage(self):
-        """Get the target language for this .ts file.
+        """
+        Get the target language for this .ts file.
 
         :return: ISO code e.g. af, fr, pt_BR
         :rtype: String
@@ -399,7 +443,8 @@ class tsfile(lisa.LISAfile):
         return data.normalize_code(self.header.get("language"))
 
     def settargetlanguage(self, targetlanguage):
-        """Set the target language for this .ts file to *targetlanguage*.
+        """
+        Set the target language for this .ts file to *targetlanguage*.
 
         :param targetlanguage: ISO code e.g. af, fr, pt_BR
         :type targetlanguage: String
@@ -408,7 +453,7 @@ class tsfile(lisa.LISAfile):
             self.header.set("language", targetlanguage)
 
     def _createcontext(self, contextname, comment=None):
-        """Creates a context node with an optional comment"""
+        """Creates a context node with an optional comment."""
         context = etree.SubElement(
             self.document.getroot(), self.namespaced(self.bodyNode)
         )
@@ -439,7 +484,8 @@ class tsfile(lisa.LISAfile):
     def addunit(
         self, unit, new=True, contextname=None, comment=None, createifmissing=True
     ):
-        """Adds the given unit to the last used body node (current context).
+        """
+        Adds the given unit to the last used body node (current context).
 
         If the contextname is specified, switch to that context (creating it if
         allowed by createifmissing).
@@ -456,7 +502,8 @@ class tsfile(lisa.LISAfile):
         return unit
 
     def _switchcontext(self, contextname, comment, createifmissing=False):
-        """Switch the current context to the one named contextname, optionally
+        """
+        Switch the current context to the one named contextname, optionally
         creating it if it doesn't exist.
         """
         self._contextname = contextname
